clear all
set matsize 10000
set maxvar 50000
set more off

cd "\IRI data"

*** Program to estimate frozen dinner prices (including heterogeneity by brand)

	import delimited "fzdinent_panel.csv"
	drop f d pr year qtrid
	drop if l2 == "FZ HANDHELD ENTREES (NON-BREAKF"
	drop product_type form size l2

** Setup
	rename iri_key stores
	rename week weekid
	replace weekid = weekid - 1113
	egen upc = group(colupc)
	egen id = group(stores upc)
	drop colupc
	xtset id weekid
	
	rename stores iri_key
	merge m:1 iri_key using stores_market.dta
	keep if _merge==3
	drop _merge
	rename iri_key stores
	encode market, gen(mkt)
	drop market
	
** Restrict sample
	by upc, sort: egen min = min(weekid)
	by upc, sort: egen max = max(weekid)
	gen T = max-min
	drop if T < 26
	
	qui unique stores, by(upc) gen(N)
	drop if N < 5 & strpos(product,"PRIVATE LABEL")==0
	
	drop min max T N
	
** Create WM post-entry and entry week indicator
	rename stores iri_key
	merge m:1 iri_key using entries_wide_11.dta
	drop if _merge==2
	drop _merge
	rename iri_key stores

	rename wmid* idwm*
	drop idwm*
	forvalues i=1/19 {
		capture gen wm`i' = (weekid >= week`i')
		capture gen enter`i' = (weekid == week`i')
		capture replace dis`i' = 0 if wm`i' == 0
		capture drop week`i'
		}
	egen wm = rowtotal(wm*)
	egen enter = rowtotal(enter*)
	drop wm1-enter12

	* Distance spline
	forvalues s=1/1 {
		forvalues i=1/24 {
			capture gen I_`i'_`s' = (dis`i' <= `s' & dis`i' > 0 )
			}
		egen wm_`s' = rowtotal(I_*_`s')
		drop I*
		}

	forvalues s=3(2)11 {
		local s0 = `s'-2
		forvalues i=1/24 {
			capture gen I_`i'_`s' = (dis`i' <= `s' & dis`i' > `s0' )
			}
		egen wm_`s' = rowtotal(I_*_`s')
		drop I*
		}
	drop dis*
	compress
	
** Merge in store names
	rename stores iri_key
	merge m:1 iri_key using store_names.dta
	drop if _merge == 2
	drop _merge
	rename iri_key stores
	
	* Merge in chain info
	merge m:1 name using chain.dta
	drop _merge
	
	gen missing_chain = (chainid ==.)
	
	replace firmtype = 3 if firmtype == 4
	encode name, gen(chain)
	replace chain = 0 if missing_chain == 1
	
	drop name
	compress
	
** Treatment groups
	by stores, sort: egen treat_nwm = max(wm)
*	by stores, sort: egen wm0 = min(wm)
	
*	gen wm_diff = treat_nwm - wm0

** Brands
*	bigtab product
	gen stouffers = (strpos(product,"STOUFFERS")>0)
	gen weight = (strpos(product,"WEIGHT")>0)
	gen banquet = (strpos(product,"BANQUET")>0)
	gen healthy_choice = (strpos(product,"HEALTHY CHOICE")>0)
	gen private = (strpos(product,"PRIVATE LABEL")>0)
	gen kid_cuisine = (strpos(product,"KID CUISINE")>0)
	gen amys = (strpos(product,"AMYS")>0)
	gen boston_market = (strpos(product,"BOSTON MARKET")>0)
	gen marie = (strpos(product,"MARIE")>0)
	gen michelinas = (strpos(product,"MICHELINAS")>0)
	gen swanson = (strpos(product,"SWANSON")>0)
	
	egen other = rowtotal(stouffers-swanson)
	replace other = 1-other
	
	drop product
	compress
	
** Create variables
	merge m:1 monthid using cpi.dta
	drop _merge
	
	gen ppvol = (dollars / (units * vol_eq))  / cpi * 100
	gen logp = log(ppvol)
	
	drop units vol_eq monthid year month
	compress
	
	gen wm_lt7 = wm_1+wm_3+wm_5+wm_7
	gen wm_lt5 = wm_1+wm_3+wm_5

*** Summaries
	foreach var of varlist stouffers-other {
		summarize ppvol if `var' == 1, detail
}

*** Brand prices
	cd "\Results"

	foreach var of varlist wm_lt5 {
		reghdfe logp enter `var', a(i.mkt#i.upc#i.week id) cluster(stores) keepsing
			outreg2 using final_fzdinent, excel
		reghdfe logp enter c.`var'#c.(stouffers-other), a(i.mkt#i.upc#i.week id) cluster(stores) keepsing
			outreg2 using final_fzdinent, excel
		}
		
*** Brand revenues
	gen brand=.
	local j=0
	foreach var of varlist stouffers-other {
		replace brand = `j'+1 if `var'==1
		local j=`j'+1
		}
	
	gen revenue = dollars / cpi * 100
	
	collapse (sum) revenue, by(stores brand weekid wm enter mkt wm_1-wm_11 treat_nwm wm_lt*)
	
	egen storesbrand = group(stores brand)
	drop if storesbrand==.
		
	xtset storesbrand weekid
	
	gen logrev = log(revenue)
	
	compress
	
	foreach var of varlist wm_lt5 {
		reghdfe logrev enter `var' c.weekid#i.brand c.weekid#c.weekid#i.brand c.weekid#i.mkt c.weekid#c.weekid#i.mkt c.weekid#i.treat_nwm c.weekid#c.weekid#i.treat_nwm, a(weekid storesbrand) cluster(stores) keepsing
			outreg2 using final_fzdinent_rev, excel
		reghdfe logrev enter c.`var'#i.brand c.weekid#i.brand c.weekid#c.weekid#i.brand c.weekid#i.mkt c.weekid#c.weekid#i.mkt c.weekid#i.treat_nwm c.weekid#c.weekid#i.treat_nwm, a(weekid storesbrand) cluster(stores) keepsing
			outreg2 using final_fzdinent_rev, excel
		}	
